# sl-up
An interactive TUI smartlog for [Sapling SCM](https://github.com/facebook/sapling), like git-sl-up but written in python3 and based on `curses`.

This is my own personal implementation for a tool available internally at Meta. FWIW, I do not have access to that tool's code so if they choose to open source the internal tool at any time, you should prefer that one over mine. I would ;) 


## Installation
```
$ pipx install git+https://github.com/vuduchild/sl-up.git
```
